@@ -23,7 +23,6 @@
 #include <KIO/OpenUrlJob>
 #include <KIO/JobUiDelegate>
 #include <KGuiItem>
-#include <kio_version.h>
 #include <KIO/StatJob>
 #include <KIO/CopyJob>
 #include <KJobWidgets>
@@ -169,15 +168,15 @@ HighscoresWidget::HighscoresWidget(QWidget *parent)
         QUrl url = internal->queryUrl(ManagerPrivate::Scores);
         _scoresUrl = new KUrlLabel(url.url(),
                                    i18n("View world-wide highscores"), this);
-        connect(_scoresUrl, QOverload<>::of(&KUrlLabel::leftClickedUrl),
-                this, &HighscoresWidget::handleUrlClicked);
+        connect(_scoresUrl, qOverload<>(&KUrlLabel::leftClickedUrl), this,
+                &HighscoresWidget::handleUrlClicked);
         vbox->addWidget(_scoresUrl);
 
         url = internal->queryUrl(ManagerPrivate::Players);
         _playersUrl = new KUrlLabel(url.url(),
                                     i18n("View world-wide players"), this);
-        connect(_playersUrl, QOverload<>::of(&KUrlLabel::leftClickedUrl),
-                this, &HighscoresWidget::handleUrlClicked);
+        connect(_playersUrl, qOverload<>(&KUrlLabel::leftClickedUrl), this,
+                &HighscoresWidget::handleUrlClicked);
         vbox->addWidget(_playersUrl);
     }
     load(-1);
@@ -221,7 +220,7 @@ HighscoresDialog::HighscoresDialog(int rank, QWidget *parent)
 {
 //     kDebug(11001) << ": HighscoresDialog";
 
-    setWindowTitle( i18n("Highscores") );
+    setWindowTitle(i18nc("@title:window", "Highscores"));
 // TODO    setButtons( Close|User1|User2 );
 // TODO    setDefaultButton( Close );
     if ( internal->nbGameTypes()>1 )
@@ -405,7 +404,7 @@ ConfigDialog::ConfigDialog(QWidget *parent)
 {
 //     kDebug(11001) << ": ConfigDialog";
     
-    setWindowTitle( i18n("Configure Highscores") );
+    setWindowTitle(i18nc("@title:window", "Configure Highscores"));
     setModal( true );
     
     QWidget *page = nullptr;
@@ -598,7 +597,7 @@ AskNameDialog::AskNameDialog(QWidget *parent)
 {
 //     kDebug(11001) << ": AskNameDialog";
 
-    setWindowTitle( i18n("Enter Your Nickname") );
+    setWindowTitle(i18nc("@title:window", "Enter Your Nickname"));
 
     internal->hsConfig().readCurrentConfig();
     QVBoxLayout *top = new QVBoxLayout;
